import Vue from 'vue'
import VueRouter, { RouteConfig } from 'vue-router'
import dashboard from '@/views/projects/dashboard.vue'
import login from '@/views/login.vue'
import security from '@/views/accountSettings/security.vue'
import apiKeys from '@/views/projects/api/apiKeys.vue'
import addApiKeys from '@/views/projects/api/add.vue'
import editApiKeys from '@/views/projects/api/edit.vue'
import webhooks from '@/views/projects/user/webhooks.vue'
import addWebhook from '@/views/projects/user/add.vue'
import editWebhook from '@/views/projects/user/edit.vue'
import plan from '@/views/billing/plan.vue'

Vue.use(VueRouter)

const routes: Array<RouteConfig> = [
  {
    path: '/',
    redirect: '/dashboard'
  },
  {
    path: '/dashboard',
    name: 'home',
    component: dashboard
  },
  {
    path: '/login',
    name: 'login',
    component: login
  },
  {
    path: '/user/password',
    name: 'security',
    component: security
  },
  {
    path: '/api/keys',
    name: 'apiKeys',
    component: apiKeys,
    children: [
      {
        path: 'new-project',
        name: 'addApiKeys',
        component: addApiKeys,
        meta: {
          showfater: false
        }
      },
      {
        path: 'edit-project',
        name: 'editApiKeys',
        component: editApiKeys,
        meta: {
          showfater: false
        }
      }
    ],
    meta: {
      showfater: true
    }
  },
  {
    path: '/user/webhooks',
    name: 'webhooks',
    component: webhooks,
    children: [
      {
        path: 'new-webhook',
        name: 'addWebhook',
        component: addWebhook,
        meta: {
          showfater: false
        }
      },
      {
        path: 'edit-webhook',
        name: 'editWebhook',
        component: editWebhook,
        meta: {
          showfater: false
        }
      }
    ],
    meta: {
      showfater: true
    }
  },
  {
    path: '/billing/plan',
    name: 'plan',
    component: plan
  }
]

const router = new VueRouter({
  mode: 'history',
  base: process.env.BASE_URL,
  routes
})

// 是否登录，未登录跳转登录页
router.beforeEach((to, from, next) => {
  if (to.path === '/login') {
    next()
  } else {
    if (from.path === '/login' && localStorage.getItem('isAuth') === 'true') {
      next()
    } else {
      if (localStorage.getItem('isAuth') === 'true') {
        next()
      } else {
        next('/login')
      }
    }
  }
})

export default router
